##
# This file is part of WhatWeb and may be subject to
# redistribution and commercial restrictions. Please see the WhatWeb
# web site for more information on licensing and terms of use.
# https://morningstarsecurity.com/research/whatweb
##
Plugin.define do
name "WordpressSuperCache"
authors [
  "Patrik Wallstrom",
  # v0.2 # removed :certainty=>100
  # v0.3 # Changed Wallström to Wallstrom
]
version "0.3"
description "Cache functionality for Wordpress - http://wordpress.org/extend/plugins/wp-super-cache/"


matches [
{:name=>"supercache comment",
:regexp=>/^<!-- Cached page generated by WP-Super-Cache on /}
]

end

